package jp.ad.iij.openmiopon;

import java.lang.reflect.Field;

import android.net.Uri;
import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.text.InputType;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.Window;
import android.webkit.ConsoleMessage;
import android.webkit.JavascriptInterface;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.webkit.WebSettings.RenderPriority;
import android.widget.EditText;
import android.widget.Toast;

public class MainActivity extends Activity {

	private static final String TAG = MainActivity.class.getSimpleName();
	private static final String OPENMIOPON_CALLBACK = "jp.ad.iij.openmiopon://cb";
	private WebView web;

	@SuppressWarnings("deprecation")
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		// ウィンドウタイトルバー非表示
		requestWindowFeature(Window.FEATURE_NO_TITLE);

		setContentView(R.layout.activity_main);

		// WebView
		web = (WebView)findViewById(R.id.webView1);

		// console.logを出力する設定
		web.setWebChromeClient(new WebChromeClient() {
			public boolean onConsoleMessage(ConsoleMessage cm) {
				Log.d(TAG, cm.message());
				return true;
			}
		});

//		web.setWebViewClient(new WebViewClient() {
//			@Override
//			public boolean shouldOverrideUrlLoading(WebView view, String url) {
//				// api.iijmio.jpという文字列を含むリンクURLの場合ブラウザアプリ起動
//				if (-1 != url.indexOf("api.iijmio.jp")) {
//					web.stopLoading();
//					Intent i = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
//					startActivity(i);
//					return false;
//				}
//				return super.shouldOverrideUrlLoading(view, url);
//			}
//		});
		
		web.setBackgroundColor(0);
		web.setVerticalScrollbarOverlay(true);
		
		web.getSettings().setJavaScriptEnabled(true);
		web.getSettings().setBuiltInZoomControls(false);
		web.getSettings().setSupportZoom(false);
		web.getSettings().setDomStorageEnabled(true);
		web.getSettings().setDatabaseEnabled(true);

		String databasePath = getApplicationContext().getDir("localstorage", Context.MODE_PRIVATE).getPath();
		web.getSettings().setDatabasePath(databasePath);

		String userAgentString = web.getSettings().getUserAgentString();
		Log.d("UserAgent:", userAgentString);

		// JellyBean以降必要
		if(android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.JELLY_BEAN) {
			web.getSettings().setAllowUniversalAccessFromFileURLs(true);
			web.getSettings().setAllowFileAccessFromFileURLs(true);
		}

		// マルチタッチを有効にしたまま、zoom controlを消す
		try {
			Field nameField = web.getSettings().getClass().getDeclaredField("mBuiltInZoomControls");
			nameField.setAccessible(true);
			nameField.set(web.getSettings(), false);
		} catch (Exception e) {
			e.printStackTrace();
			web.getSettings().setBuiltInZoomControls(false);
		}

		// JavaScriptを有効にする
		web.addJavascriptInterface(new JsObj(this), "app");

		// クエリー文字列からトークンを取得する
//		getTokenFromAuth(intent);
		
		// HTMLのロード
		web.loadUrl("file:///android_asset/openmiopon.html");
		
	}

	@Override
	public void onNewIntent(Intent intent) {
		super.onNewIntent(intent);
		
		// クエリー文字列からトークンを取得する
		getTokenFromAuth(intent);

	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

		switch (item.getItemId()) {
		case R.id.action_refresh:

			web.reload();
			break;

		case R.id.action_settings:
			{
//				Intent intent = new Intent(MainActivity.this, Settings.class);
//				startActivityForResult(intent, requestCode);
			}
			break;

		case R.id.action_logout:
		{
			// 確認ダイアログを表示
//			showLogoutDialog();
		}
		break;

		case R.id.action_close:
//			// 終了時キャッシュクリア？
//			if (Settings.isUseClearCacheExit(this)) {
//				// キャッシュをクリアする
//				clearCache();
//			}
			finish();
			break;
		}

		return true;
	}
	
	// JSから呼ばれる
	final class JsObj {

		private Context con;

		public JsObj(Context con) {
			this.con = con;
		}

		@JavascriptInterface
		public void log(String str) {
			Log.d(TAG, "js: " + str);
			return;
		}
		
		@JavascriptInterface
		public void invalidateView() {
			runOnUiThread(new Runnable() {
				public void run() {
					web.invalidate();
				}
			});
		}
		
		@JavascriptInterface
		public void openDefaultBrowser(String url) {
			Intent i = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
			startActivity(i);
		}


	}

	private void getTokenFromAuth(Intent intent) {

		// インテントを取得
		String action = intent.getAction();
		if (Intent.ACTION_VIEW.equals(action)) {
			Uri uri = intent.getData();
			if ((uri != null) && (uri.toString().startsWith(OPENMIOPON_CALLBACK))) {
				Log.d(TAG, "calling callbackFromAuth" + uri.toString());
				web.loadUrl("javascript:callbackFromAuth('" + uri.toString() + "');");
			}
		}
	}
}
